@@ -2,25 +2,6 @@ context("Predict model")
 
 test_that("Check predict.disag_model function works as expected", {
 
-  skip_if_not_installed('INLA')
-  skip_on_cran()
-
-  result <- disag_model(test_data, iterations = 1000,
-                        iid = TRUE,
-                        field = TRUE,
-                        family = 'poisson',
-                        link = 'log',
-                        priors = list(priormean_intercept = 0,
-                                      priorsd_intercept = 0.1,
-                                      priormean_slope = 0.0,
-                                      priorsd_slope = 0.1,
-                                      prior_rho_min = 5,
-                                      prior_rho_prob = 0.01,
-                                      prior_sigma_max = 0.1,
-                                      prior_sigma_prob = 0.01,
-                                      prior_iideffect_sd_max = 0.0001,
-                                      prior_iideffect_sd_prob = 0.01))
-
   pred2 <- predict(result)
 
   expect_is(pred2, 'disag_prediction')
@@ -67,9 +48,9 @@ test_that("Check predict.disag_model function works as expected", {
 
   # For a model with no field or iid
 
-  result <- disag_model(test_data, iterations = 100, field = FALSE, iid = FALSE)
+  result2 <- disag_model(test_data, iterations = 100, field = FALSE, iid = FALSE)
 
-  pred2 <- predict(result)
+  pred2 <- predict(result2)
 
   expect_is(pred2, 'disag_prediction')
   expect_equal(length(pred2), 2)
@@ -94,27 +75,12 @@ test_that("Check predict.disag_model function works as expected", {
 
 
 
-test_that("Check predict.disag_model function works with newdata", {
+test_that("Check predict.disag_model function works with new data", {
 
-  skip_if_not_installed('INLA')
-  skip_on_cran()
-
-  result <- disag_model(test_data, field = FALSE, iid = TRUE, iterations = 100,
-                        priors = list(priormean_intercept = 0,
-                                      priorsd_intercept = 1,
-                                      priormean_slope = 0.0,
-                                      priorsd_slope = 0.4,
-                                      prior_rho_min = 1,
-                                      prior_rho_prob = 0.01,
-                                      prior_sigma_max = 0.1,
-                                      prior_sigma_prob = 0.01,
-                                      prior_iideffect_sd_max = 0.0001,
-                                      prior_iideffect_sd_prob = 0.01))
-
-  newdata <- terra::crop(c(r, r2), c(0, 10, 0, 10))
-  names(newdata) <- c('layer1', 'layer2')
+  new_data <- terra::crop(c(r, r2), c(0, 10, 0, 10))
+  names(new_data) <- c('layer1', 'layer2')
   pred1 <- predict(result)
-  pred2 <- predict(result, newdata, predict_iid = TRUE, N = 5)
+  pred2 <- predict(result, new_data, predict_iid = TRUE, N = 5)
 
   expect_is(pred2, 'disag_prediction')
   expect_equal(length(pred2), 2)
@@ -124,7 +90,7 @@ test_that("Check predict.disag_model function works with newdata", {
   expect_equal(length(pred2$mean_prediction), 4)
   expect_equal(names(pred2$mean_prediction), c('prediction', 'field', 'iid', 'covariates'))
   expect_is(pred2$mean_prediction$prediction, 'SpatRaster')
-  expect_true(is.null(pred2$mean_prediction$field))
+  expect_true(!is.null(pred2$mean_prediction$field))
   expect_is(pred2$mean_prediction$iid, 'SpatRaster')
   expect_is(pred2$mean_prediction$covariates, 'SpatRaster')
 
@@ -141,52 +107,30 @@ test_that("Check predict.disag_model function works with newdata", {
 
 })
 
-test_that('Check that check_newdata works', {
+test_that('Check that check_new_data works', {
 
-  skip_if_not_installed('INLA')
-  skip_on_cran()
+  new_data <- terra::crop(c(r, r2), c(0, 10, 0, 10))
+  names(new_data) <- c('layer1', 'layer2')
 
-  result <- disag_model(test_data, field = FALSE, iterations = 100)
-
-  newdata <- terra::crop(c(r, r2), c(0, 10, 0, 10))
-  names(newdata) <- c('layer1', 'layer2')
-
-  nd1 <- check_newdata(newdata, result)
+  nd1 <- check_new_data(new_data, result)
   expect_is(nd1, 'SpatRaster')
 
-  nn <- newdata[[1]]
+  nn <- new_data[[1]]
   names(nn) <- 'extra_unneeded'
-  newdata2 <- c(newdata, nn)
-  expect_error(check_newdata(newdata2, result), NA)
+  new_data2 <- c(new_data, nn)
+  expect_error(check_new_data(new_data2, result), NA)
 
-  newdata3 <- newdata[[1]]
-  expect_error(check_newdata(newdata3, result), 'All covariates')
+  new_data3 <- new_data[[1]]
+  expect_error(check_new_data(new_data3, result), 'All covariates')
 
-  newdata4 <- result$data$covariate_data
-  expect_error(check_newdata(newdata4, result), 'newdata should be NULL or')
+  new_data4 <- result$data$covariate_data
+  expect_error(check_new_data(new_data4, result), 'new_data should be NULL or')
 
 
 })
 
 test_that('Check that setup_objects works', {
 
-  skip_if_not_installed('INLA')
-  skip_on_cran()
-
-  result <- disag_model(test_data, iterations = 100,
-                        iid = TRUE,
-                        field = TRUE,
-                        priors = list(priormean_intercept = 0,
-                                      priorsd_intercept = 1,
-                                      priormean_slope = 0.0,
-                                      priorsd_slope = 0.4,
-                                      prior_rho_min = 1,
-                                      prior_rho_prob = 0.01,
-                                      prior_sigma_max = 0.1,
-                                      prior_sigma_prob = 0.01,
-                                      prior_iideffect_sd_max = 0.01,
-                                      prior_iideffect_sd_prob = 0.01))
-
   objects <- setup_objects(result)
 
   expect_is(objects, 'list')
@@ -195,9 +139,9 @@ test_that('Check that setup_objects works', {
   expect_is(objects$field_objects, 'list')
   expect_true(is.null(objects$iid_objects))
 
-  newdata <- terra::crop(c(r, r2), c(0, 180, -90, 90))
-  names(newdata) <- c('layer1', 'layer2')
-  objects2 <- setup_objects(result, newdata)
+  new_data <- terra::crop(c(r, r2), c(0, 180, -90, 90))
+  names(new_data) <- c('layer1', 'layer2')
+  objects2 <- setup_objects(result, new_data)
 
   expect_is(objects2, 'list')
   expect_equal(length(objects2), 3)
@@ -217,23 +161,6 @@ test_that('Check that setup_objects works', {
 
 test_that('Check that predict_single_raster works', {
 
-  skip_if_not_installed('INLA')
-  skip_on_cran()
-
-  result <- disag_model(test_data, iterations = 100,
-                        iid = TRUE,
-                        field = TRUE,
-                        priors = list(priormean_intercept = 0,
-                                      priorsd_intercept = 1,
-                                      priormean_slope = 0.0,
-                                      priorsd_slope = 0.4,
-                                      prior_rho_min = 1,
-                                      prior_rho_prob = 0.01,
-                                      prior_sigma_max = 0.1,
-                                      prior_sigma_prob = 0.01,
-                                      prior_iideffect_sd_max = 0.01,
-                                      prior_iideffect_sd_prob = 0.01))
-
   objects <- setup_objects(result)
 
   pars <- result$obj$env$last.par.best
